@@ -1,14 +1,11 @@
 use strict;
 use warnings;
 package Devel::REPL::Meta::Plugin;
-BEGIN {
-  $Devel::REPL::Meta::Plugin::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $Devel::REPL::Meta::Plugin::VERSION = '1.003025';
-}
+
+our $VERSION = '1.003027';
 
 use Moose;
+use namespace::autoclean;
 
 extends 'Moose::Meta::Role';
 
