@@ -1,6 +1,13 @@
+use strict;
+use warnings;
 package Devel::REPL::Plugin::CompletionDriver::Turtles;
+# ABSTRACT: Complete Turtles-based commands
+
+our $VERSION = '1.003027';
+
 use Devel::REPL::Plugin;
-use namespace::clean -except => [ "meta" ];
+use Devel::REPL::Plugin::Completion;    # die early if cannot load
+use namespace::autoclean;
 
 sub BEFORE_PLUGIN {
     my $self = shift;
@@ -24,8 +31,8 @@ around complete => sub {
         map { "$pre$_" }
         grep { $_ =~ $filter }
         map { /^expr?_command_(\w+)/ ? $1 : () }
-        map { $_->{name} }
-        $self->meta->compute_all_applicable_methods
+        map { $_->name }
+        $self->meta->get_all_methods
       ),
     );
   } else {
@@ -37,13 +44,27 @@ __PACKAGE__
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::CompletionDriver::Turtles - Complete Turtles-based commands
 
+=head1 VERSION
+
+version 1.003027
+
 =head1 AUTHOR
 
 Yuval Kogman E<lt>nothingmuch@woobling.orgE<gt>
 
-=cut
+=head1 COPYRIGHT AND LICENSE
 
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
