@@ -1,15 +1,13 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::DDS;
-BEGIN {
-  $Devel::REPL::Plugin::DDS::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $Devel::REPL::Plugin::DDS::VERSION = '1.003025';
-}
+# ABSTRACT: Format results with Data::Dump::Streamer
+
+our $VERSION = '1.003027';
 
 use Devel::REPL::Plugin;
 use Data::Dump::Streamer ();
+use namespace::autoclean;
 
 around 'format_result' => sub {
    my $orig = shift;
@@ -35,10 +33,18 @@ around 'format_result' => sub {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::DDS - Format results with Data::Dump::Streamer
 
+=head1 VERSION
+
+version 1.003027
+
 =head1 SYNOPSIS
 
  # in your re.pl file:
@@ -57,5 +63,15 @@ Devel::REPL::Plugin::DDS - Format results with Data::Dump::Streamer
 
  $
 
-=cut
+=head1 AUTHOR
 
+Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
