@@ -1,10 +1,10 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::Packages;
-BEGIN {
-  $Devel::REPL::Plugin::Packages::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::Packages::VERSION = '1.003026';
+# ABSTRACT: Keep track of which package the user is in
+
+our $VERSION = '1.003027';
+
 use Devel::REPL::Plugin;
 use namespace::autoclean;
 
@@ -50,23 +50,36 @@ around 'eval' => sub {
   return $self->$orig(@args);
 };
 
-package Devel::REPL::Plugin::Packages::DefaultScratchpad;
-BEGIN {
-  $Devel::REPL::Plugin::Packages::DefaultScratchpad::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::Packages::DefaultScratchpad::VERSION = '1.003026';
+package # hide from PAUSE
+    Devel::REPL::Plugin::Packages::DefaultScratchpad;
+
 # declare empty scratchpad package for cleanliness
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::Packages - Keep track of which package the user is in
 
 =head1 VERSION
 
-version 1.003026
+version 1.003027
+
+=head1 AUTHOR
+
+Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
